@@ -1,7 +1,7 @@
 /*
  * endx2xml.c
  * 
- * Copyright (c) Chris Putnam 2006-8
+ * Copyright (c) Chris Putnam 2006-2010
  *
  * Source code and program released under the GPL
  *
@@ -9,17 +9,22 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "bibutils.h"
+#include "endxmlin.h"
+#include "modsout.h"
 #include "tomods.h"
 #include "bibprog.h"
 
 char help1[] =  "Converts a Endnote XML file (v8 or later) into MODS XML\n\n";
 char help2[] = "endnotexml_file";
 
+const char progname[] = "endx2xml";
+
 int
 main( int argc, char *argv[] )
 {
 	param p;
-	bibl_initparams( &p, BIBL_ENDNOTEXMLIN, BIBL_MODSOUT, "endx2xml" );
+	endxmlin_initparams( &p, progname );
+	modsout_initparams( &p, progname );
 	tomods_processargs( &argc, argv, &p, help1, help2 );
 	bibprog( argc, argv, &p );
 	bibl_freeparams( &p );
