@@ -1,7 +1,7 @@
 /*
  * isi2xml.c
  *
- * Copyright (c) Chris Putnam 2004-8
+ * Copyright (c) Chris Putnam 2004-2010
  *
  * Program and source code released under the GPL
  *
@@ -9,17 +9,22 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "bibutils.h"
+#include "isiin.h"
+#include "modsout.h"
 #include "tomods.h"
 #include "bibprog.h"
 
 char help1[] = "Converts a ISI reference file into MODS XML\n\n";
 char help2[] = "isi_file";
 
+const char progname[] = "isi2xml";
+
 int
 main( int argc, char *argv[] )
 {
 	param p;
-	bibl_initparams( &p, BIBL_ISIIN, BIBL_MODSOUT, "isi2xml" );
+	isiin_initparams( &p, progname );
+	modsout_initparams( &p, progname );
 	tomods_processargs( &argc, argv, &p, help1, help2 );
 	bibprog( argc, argv, &p );
 	bibl_freeparams( &p );
