@@ -1,7 +1,7 @@
 /*
  * ebiin.h
  *
- * Copyright (c) Chris Putnam 2004-2009
+ * Copyright (c) Chris Putnam 2004-2010
  *
  * Program and source code released under the GPL
  *
@@ -12,11 +12,15 @@
 #include "newstr.h"
 #include "fields.h"
 #include "reftypes.h"
+#include "bibutils.h"
 
 extern int ebiin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, newstr *line, newstr *reference, int *fcharset );
 extern int ebiin_processf( fields *ebiin, char *data, char *filename, long nref );
 extern void ebiin_convertf( fields *ebiin, fields *info, int reftype, int verbose, variants *all, int nall );
 
+extern void ebiin_initparams( param *p, const char *progname );
+
+
 extern variants med_all[];
 extern int med_nall;
 
