@@ -1,7 +1,7 @@
 /*
  * newstring.h
  *
- * Copyright (c) Chris Putnam 1999-2008
+ * Copyright (c) Chris Putnam 1999-2009
  *
  * Source code released under the GPL
  *
@@ -18,9 +18,16 @@ typedef struct newstr {
 	unsigned long len;
 }  newstr;
 
-newstr *newstr_new      ( void ); 
-void newstr_init        ( newstr *s );
-void newstr_free        ( newstr *s );
+newstr *newstr_new         ( void ); 
+
+void    newstr_init        ( newstr *s );
+void    newstr_empty       ( newstr *s );
+void    newstr_free        ( newstr *s );
+
+void    newstrs_init       ( newstr *s, ... );
+void    newstrs_empty      ( newstr *s, ... );
+void    newstrs_free       ( newstr *s, ... );
+
 newstr *newstr_strdup   ( char *buf );
 void newstr_addchar     ( newstr *s, char newchar );
 void newstr_strcat      ( newstr *s, char *addstr );
@@ -35,7 +42,6 @@ void newstr_fprintf     ( FILE *fp, newstr *s );
 int  newstr_fget        ( FILE *fp, char *buf, int bufsize, int *pbufpos,
                           newstr *outs );
 int  newstr_findreplace ( newstr *s, char *find, char *replace );
-void newstr_empty       ( newstr *s );
 void newstr_toupper     ( newstr *s );
 void newstr_trimendingws( newstr *s );
 void newstr_swapstrings ( newstr *s1, newstr *s2 );
